@@ -195,7 +195,7 @@ void GameManager::setInGameSelectPlayer(){
 	myMenu_->setTitle("Choose Players"+actualDir_);
 	std::vector<BoxElement *> ll;
 	int i=0;
-	int nbPosibbili=board_->getNbPlayers();
+	
 	for (i=0;i<board_->getNbPlayers();i++)
 	{
 		std::stringstream val;
@@ -279,7 +279,7 @@ void GameManager::incIndexMenu()
 	actualIndexMenu_++;
 	if (actualIndexMenu_<0)
 	{
-		actualIndexMenu_=myMenu_->getMenuElements().size()-1;
+		actualIndexMenu_=(int)myMenu_->getMenuElements().size()-1;
 	}
 	if (((unsigned int)actualIndexMenu_)>myMenu_->getMenuElements().size())
 	{
@@ -292,7 +292,7 @@ void GameManager::decIndexMenu()
 	actualIndexMenu_--;
 	if (actualIndexMenu_<0)
 	{
-		actualIndexMenu_=myMenu_->getMenuElements().size()-1;
+		actualIndexMenu_=(int)myMenu_->getMenuElements().size()-1;
 	}
 	if (((unsigned int)actualIndexMenu_)>myMenu_->getMenuElements().size())
 	{
@@ -813,7 +813,7 @@ void GameManager::transitionMapPlayers(){
 		message<<"Generate Map for "<<playersGen<<" players .\n";
 		meesBox_->setMessage(message.str());
 		drawer_->draw(meesBox_);
-		void (*writesmessage)(std::string title,std::string message) ;
+		//void (*writesmessage)(std::string title,std::string message) ;
 		
 		
 		Case *pp=mm.generateMap(playersGen,xsizeGen,ysizeGen);
@@ -882,7 +882,9 @@ void GameManager::transitionInNameHelp(){
 	
 	}
 }
-
+#ifndef DATADIR
+#define DATADIR 'data'
+#endif
 void GameManager::transitionNewLocalMenu(){
 
 
@@ -1073,7 +1075,7 @@ void GameManager::transitionInGameSave(CommandManager::ACTIONKEY KEY){
 
 bool GameManager::isDir(std::string pp)
 {
-	FILE * pFile;
+	
 	//pFile = fopen (pp.c_str(),"r");
 #if defined __CYGWIN32__ 
 	
@@ -1151,7 +1153,7 @@ bool GameManager::isGameOldFormat(std::string pp)
 		
 		char MagicWord[6];
 		MagicWord[5]=0;
-		int result = fread (MagicWord,1,5,pFile);
+		size_t result = fread (MagicWord,1,5,pFile);
 		if (result != 5)
 		{
 			rettVal=false;
@@ -1196,7 +1198,7 @@ void GameManager::transitionNewLocalOpenMenu(){
 	if (actualIndexMenu_<0) 
 		actualIndexMenu_=0;
 	if (actualIndexMenu_>=myMenu_->getMenuElements().size()) 
-		actualIndexMenu_=myMenu_->getMenuElements().size();
+		actualIndexMenu_=(int)myMenu_->getMenuElements().size();
 	
 	if (actualIndexMenu_==0) 
 	{
@@ -1205,7 +1207,7 @@ void GameManager::transitionNewLocalOpenMenu(){
 		return;
 	}
 	if (((unsigned int )actualIndexMenu_)>myMenu_->getMenuElements().size()) 
-		actualIndexMenu_=myMenu_->getMenuElements().size()-1;
+		actualIndexMenu_=(int)myMenu_->getMenuElements().size()-1;
 	
 	 BoxElement *el=myMenu_->getMenuElements().at(actualIndexMenu_);
 	 LabelBoxElement *el2=dynamic_cast<LabelBoxElement*>(el);
@@ -1355,8 +1357,7 @@ void GameManager::manageInGame(CommandManager::ACTIONKEY KEY){
 	
 	}
 	bool isChanged=false;
-	bool hasMenu=false;
-	bool trySave=false;
+	
 	std::stringstream message;
 	switch (KEY)
 	{
